<?php
/* vim: set expandtab sw=4 ts=4 sts=4: */
/**
 * print css file from theme Original
 *
 * @package phpMyAdmin-theme
 * @subpackage Original
 */
?>
/* For printview */
body, table, th, td {
    color:             #000000;
    background-color:  #ffffff;
}

img {
    border: 0;
}

table, th, td {
    border-width:      0.1em;
    border-color:      #000000;
    border-style:      solid;
}

table {
    border-collapse:   collapse;
    border-spacing:    0;
}

th, td {
    padding:           0.2em;
}

th {
    font-weight:       bold;
    background-color:  #e5e5e5;
}
